@@ -1,4 +1,4 @@
-from typing import Sequence, List, Optional
+from typing import Sequence, List, Optional, Tuple
 
 import numpy as np
 import pandas as pd
@@ -9,6 +9,7 @@ from sknlp.vocab import Vocab
 
 from .classification_dataset import ClassificationDataset
 from .tagging_dataset import TaggingDataset
+from .similarity_dataset import SimilarityDataset
 
 
 class BertClassificationDataset(ClassificationDataset):
@@ -19,6 +20,7 @@ class BertClassificationDataset(ClassificationDataset):
         df: Optional[pd.DataFrame] = None,
         csv_file: Optional[str] = None,
         in_memory: bool = True,
+        no_label: bool = False,
         is_multilabel: bool = True,
         max_length: Optional[int] = None,
     ):
@@ -28,31 +30,21 @@ class BertClassificationDataset(ClassificationDataset):
             df=df,
             csv_file=csv_file,
             in_memory=in_memory,
+            no_label=no_label,
             is_multilabel=is_multilabel,
             max_length=max_length,
             text_segmenter=None,
             text_dtype=tf.string,
-            text_padding_shape=(),
-            text_padding_value=vocab.pad,
-            label_padding_value=0.0,
+            label_dtype=tf.float32,
         )
 
+    @property
+    def batch_padding_shapes(self) -> Optional[List[Tuple]]:
+        return None
+
     def _text_transform(self, text: tf.Tensor) -> str:
         return text.numpy().decode("utf-8")[: self.max_length]
 
-    def batchify(
-        self, batch_size: int, shuffle: bool = True, shuffle_buffer_size: int = 100000
-    ) -> tf.data.Dataset:
-        dataset = self._dataset
-        if shuffle:
-            if shuffle_buffer_size <= 0:
-                shuffle_buffer_size = 100000
-            dataset = dataset.shuffle(shuffle_buffer_size)
-
-        return dataset.batch(batch_size).prefetch(
-            buffer_size=tf.data.experimental.AUTOTUNE
-        )
-
 
 class BertTaggingDataset(TaggingDataset):
     def __init__(
@@ -62,6 +54,7 @@ class BertTaggingDataset(TaggingDataset):
         df: Optional[pd.DataFrame] = None,
         csv_file: Optional[str] = None,
         in_memory: bool = True,
+        no_label: bool = False,
         max_length: Optional[int] = None,
     ):
         super().__init__(
@@ -70,14 +63,50 @@ class BertTaggingDataset(TaggingDataset):
             df=df,
             csv_file=csv_file,
             in_memory=in_memory,
+            no_label=no_label,
             start_tag="[CLS]",
             end_tag="[SEP]",
             text_segmenter=None,
             max_length=max_length,
             text_dtype=tf.string,
-            text_padding_shape=(),
-            text_padding_value=vocab.pad,
+            label_dtype=tf.int32,
         )
 
+    @property
+    def batch_padding_shapes(self) -> Optional[List[Tuple]]:
+        return ((), (None,))
+
+    def _text_transform(self, text: tf.Tensor) -> str:
+        return text.numpy().decode("utf-8")[: self.max_length]
+
+
+class BertSimilarityDataset(SimilarityDataset):
+    def __init__(
+        self,
+        vocab: Vocab,
+        labels: Sequence[str],
+        df: Optional[pd.DataFrame] = None,
+        csv_file: Optional[str] = None,
+        in_memory: bool = True,
+        no_label: bool = False,
+        max_length: Optional[int] = None,
+    ):
+        super().__init__(
+            vocab,
+            labels,
+            df=df,
+            csv_file=csv_file,
+            in_memory=in_memory,
+            no_label=no_label,
+            max_length=max_length,
+            text_segmenter=None,
+            text_dtype=tf.string,
+            label_dtype=tf.float32,
+        )
+
+    @property
+    def batch_padding_shapes(self) -> Optional[List[Tuple]]:
+        return None
+
     def _text_transform(self, text: tf.Tensor) -> str:
         return text.numpy().decode("utf-8")[: self.max_length]
\ No newline at end of file
