@@ -1,4 +1,4 @@
-from typing import Sequence, List, Union, Optional
+from typing import Sequence, List, Optional, Tuple, Any
 
 import numpy as np
 import pandas as pd
@@ -8,6 +8,10 @@ from sknlp.vocab import Vocab
 from .nlp_dataset import NLPDataset
 
 
+def _combine_xy(x, y):
+    return (x, y), y
+
+
 class TaggingDataset(NLPDataset):
     def __init__(
         self,
@@ -16,16 +20,13 @@ class TaggingDataset(NLPDataset):
         df: Optional[pd.DataFrame] = None,
         csv_file: Optional[str] = None,
         in_memory: bool = True,
+        no_label: bool = False,
         start_tag: Optional[str] = None,
         end_tag: Optional[str] = None,
         max_length: Optional[int] = None,
         text_segmenter: str = "char",
         text_dtype: tf.DType = tf.int32,
         label_dtype: tf.DType = tf.int32,
-        text_padding_shape: tuple = (None,),
-        label_padding_shape: tuple = (None,),
-        text_padding_value: Union[str, int, float, None] = None,
-        label_padding_value: Union[str, int, float, None] = 0
     ):
         self.vocab = vocab
         self.start_tag = start_tag
@@ -35,16 +36,28 @@ class TaggingDataset(NLPDataset):
             df=df,
             csv_file=csv_file,
             in_memory=in_memory,
+            no_label=no_label,
             text_segmenter=text_segmenter,
             max_length=max_length,
+            na_value="",
+            column_dtypes=["str", "str"],
             text_dtype=text_dtype,
             label_dtype=label_dtype,
-            text_padding_shape=text_padding_shape,
-            label_padding_shape=label_padding_shape,
-            text_padding_value=text_padding_value or vocab[vocab.pad],
-            label_padding_value=label_padding_value,
         )
 
+    @property
+    def y(self) -> List[List[str]]:
+        if self.no_label:
+            return []
+        return [
+            data[-1].decode("utf-8").split("|")
+            for data in self._original_dataset.as_numpy_iterator()
+        ]
+
+    @property
+    def batch_padding_shapes(self) -> List[Tuple]:
+        return ((None,), (None,))
+
     def _text_transform(self, text: tf.Tensor) -> np.ndarray:
         tokens = super()._text_transform(text)
         return np.array(
@@ -62,27 +75,26 @@ class TaggingDataset(NLPDataset):
             ]
         return labels
 
-    def _combine_xy(self, x, y):
-        return (x, y), y
+    def _transform_func(self, *data) -> List[Any]:
+        text = data[0]
+        if self.no_label:
+            _text = self._text_transform(text)
+            return _text, [0 for _ in range(len(_text))]
+        label = data[1]
+        return self._text_transform(text), self._label_transform(label)
+
+    def _transform_func_out_dtype(self) -> List[tf.DType]:
+        return (self.text_dtype, self.label_dtype)
 
     def batchify(
         self,
         batch_size: int,
         shuffle: bool = True,
-        shuffle_buffer_size: int = 100000,
+        shuffle_buffer_size: Optional[int] = None,
     ) -> tf.data.Dataset:
-        dataset = self._dataset
-        if shuffle:
-            if shuffle_buffer_size <= 0:
-                shuffle_buffer_size = 100000
-            dataset = dataset.shuffle(shuffle_buffer_size)
-
-        return (
-            dataset.padded_batch(
-                batch_size,
-                padded_shapes=(self.text_padding_shape, self.label_padding_shape),
-                padding_values=(self.text_padding_value, self.label_padding_value),
-            )
-            .map(self._combine_xy)
-            .prefetch(buffer_size=tf.data.experimental.AUTOTUNE)
+        return super().batchify(
+            batch_size,
+            shuffle=shuffle,
+            shuffle_buffer_size=shuffle_buffer_size,
+            after_batch=_combine_xy,
         )
