@@ -1,12 +1,12 @@
-from typing import Sequence, List, Dict, Any, Optional
+from typing import Sequence, List, Dict, Any, Optional, Callable
 
 import tensorflow as tf
+from tensorflow.keras.activations import gelu
 from tensorflow.keras.initializers import TruncatedNormal
-from tensorflow.keras.layers import InputSpec
 from tensorflow.keras.layers.experimental.preprocessing import TextVectorization
 
 from official.modeling import activations
-from official.nlp.modeling import layers
+from official.nlp.keras_nlp import layers
 import tensorflow_text as tftext
 
 from .bert_tokenization import BertTokenizationLayer
@@ -108,6 +108,40 @@ class BertPreprocessingLayer(tf.keras.layers.Layer):
         }
 
 
+class BertPairPreprocessingLayer(BertPreprocessingLayer):
+    def call(self, inputs: List[tf.Tensor]) -> List[tf.Tensor]:
+        query, context = inputs
+        query_token_ids = self.tokenizer.tokenize(query)
+        context_token_ids = self.tokenizer.tokenize(context)
+        query_flatten_ids = query_token_ids.merge_dims(-2, -1)
+        context_flatten_ids = context_token_ids.merge_dims(-2, -1)
+        cls_ids = tf.reshape(
+            tf.tile(
+                tf.constant([self.cls_id], dtype=tf.int64), [query_token_ids.nrows()]
+            ),
+            [query_token_ids.nrows(), 1],
+        )
+        sep_ids = tf.reshape(
+            tf.tile(
+                tf.constant([self.sep_id], dtype=tf.int64), [query_token_ids.nrows()]
+            ),
+            [query_token_ids.nrows(), 1],
+        )
+        query_ids = tf.concat([cls_ids, query_flatten_ids, sep_ids], axis=1)
+        context_ids = tf.concat([context_flatten_ids, sep_ids], axis=1)
+        type_ids = tf.concat(
+            [
+                tf.zeros_like(query_ids, dtype=tf.int64),
+                tf.ones_like(context_ids, dtype=tf.int64),
+            ],
+            axis=1,
+        )
+        return (
+            tf.concat([query_ids, context_ids], axis=1, name="token_ids").to_tensor(0),
+            type_ids.to_tensor(0),
+        )
+
+
 class BertLayer(tf.keras.layers.Layer):
     """
     copy from https://github.com/tensorflow/models/blob/v2.2.0/official/nlp/modeling/networks/transformer_encoder.py.
@@ -124,7 +158,7 @@ class BertLayer(tf.keras.layers.Layer):
         max_sequence_length: int = 512,
         type_vocab_size: int = 16,
         intermediate_size: int = 3072,
-        activation: activations = activations.gelu,
+        activation: Callable = gelu,
         dropout_rate: float = 0.1,
         attention_dropout_rate: float = 0.1,
         initializer: tf.keras.initializers.Initializer = TruncatedNormal(stddev=0.02),
@@ -159,9 +193,8 @@ class BertLayer(tf.keras.layers.Layer):
         )
         # Always uses dynamic slicing for simplicity.
         self.position_embedding_layer = layers.PositionEmbedding(
+            max_sequence_length,
             initializer=initializer,
-            use_dynamic_slicing=True,
-            max_sequence_length=max_sequence_length,
             name="position_embedding",
         )
         self.type_embedding_layer = layers.OnDeviceEmbedding(
@@ -185,24 +218,24 @@ class BertLayer(tf.keras.layers.Layer):
             name="embeddings/layer_norm", axis=-1, epsilon=1e-12, dtype=tf.float32
         )
         if share_layer:
-            self.shared_layer = layers.Transformer(
-                num_attention_heads=num_attention_heads,
-                intermediate_size=intermediate_size,
-                intermediate_activation=activation,
-                dropout_rate=dropout_rate,
-                attention_dropout_rate=attention_dropout_rate,
+            self.shared_layer = layers.TransformerEncoderBlock(
+                num_attention_heads,
+                intermediate_size,
+                activation,
+                output_dropout=dropout_rate,
+                attention_dropout=attention_dropout_rate,
                 kernel_initializer=initializer,
                 name="transformer",
             )
         else:
             self.transformer_layers = []
             for i in range(num_layers):
-                layer = layers.Transformer(
-                    num_attention_heads=num_attention_heads,
-                    intermediate_size=intermediate_size,
-                    intermediate_activation=activation,
-                    dropout_rate=dropout_rate,
-                    attention_dropout_rate=attention_dropout_rate,
+                layer = layers.TransformerEncoderBlock(
+                    num_attention_heads,
+                    intermediate_size,
+                    activation,
+                    output_dropout=dropout_rate,
+                    attention_dropout=attention_dropout_rate,
                     kernel_initializer=initializer,
                     name="transformer/layer_%d" % i,
                 )
@@ -233,7 +266,7 @@ class BertLayer(tf.keras.layers.Layer):
         if self.embedding_projection is not None:
             embeddings = self.embedding_projection(embeddings)
         data = embeddings
-        attention_mask = layers.SelfAttentionMask()([data, mask])
+        attention_mask = layers.SelfAttentionMask()(data, mask)
         encoder_outputs = []
         if self.share_layer:
             for _ in range(self.num_layers):
