@@ -1,10 +1,8 @@
 from typing import Sequence, Optional, Union, Any, Dict
 import functools
-from numpy.lib.function_base import average
 
 import tensorflow as tf
 from tensorflow.keras.metrics import Precision, Recall
-import tensorflow.keras.backend as K
 from tensorflow_addons.metrics import FBetaScore
 
 
@@ -27,16 +25,16 @@ class PrecisionWithLogits(Precision):
         )
         self.logits2scores = logits2scores
         if logits2scores == "sigmoid":
-            self._l2s = K.sigmoid
+            self._l2s = tf.math.sigmoid
         elif logits2scores == "softmax":
-            self._l2s = functools.partial(K.softmax, axis=-1)
+            self._l2s = functools.partial(tf.math.softmax, axis=-1)
 
     def update_state(
         self,
         y_true: tf.Tensor,
         y_logits: tf.Tensor,
         sample_weight: Optional[tf.Tensor] = None,
-    ):
+    ) -> None:
         super().update_state(y_true, self._l2s(y_logits), sample_weight=sample_weight)
 
     def get_config(self) -> Dict[str, Any]:
@@ -62,9 +60,9 @@ class RecallWithLogits(Recall):
         )
         self.logits2scores = logits2scores
         if logits2scores == "sigmoid":
-            self._l2s = K.sigmoid
+            self._l2s = tf.math.sigmoid
         elif logits2scores == "softmax":
-            self._l2s = functools.partial(K.softmax, axis=-1)
+            self._l2s = functools.partial(tf.math.softmax, axis=-1)
 
     def update_state(
         self,
@@ -84,7 +82,7 @@ class FBetaScoreWithLogits(FBetaScore):
         num_classes: int,
         average: str = "micro",
         beta: float = 1.0,
-        threshold: float = 0.5,
+        thresholds: float = 0.5,
         name: str = "fbeta_score",
         dtype: Optional[tf.DType] = None,
         logits2scores: str = "sigmoid",
@@ -93,15 +91,15 @@ class FBetaScoreWithLogits(FBetaScore):
             num_classes,
             average=average,
             beta=beta,
-            threshold=threshold,
+            threshold=thresholds,
             name=name,
-            dtype=dtype
+            dtype=dtype,
         )
         self.logits2scores = logits2scores
         if logits2scores == "sigmoid":
-            self._l2s = K.sigmoid
+            self._l2s = tf.math.sigmoid
         elif logits2scores == "softmax":
-            self._l2s = functools.partial(K.softmax, axis=-1)
+            self._l2s = functools.partial(tf.math.softmax, axis=-1)
 
     def update_state(
         self,
@@ -112,4 +110,10 @@ class FBetaScoreWithLogits(FBetaScore):
         super().update_state(y_true, self._l2s(y_logits), sample_weight=sample_weight)
 
     def get_config(self) -> Dict[str, Any]:
-        return {**super().get_config(), "logits2scores": self.logits2scores}
\ No newline at end of file
+        configs = super().get_config()
+        configs.pop("threshold", None)
+        return {
+            **configs,
+            "logits2scores": self.logits2scores,
+            "thresholds": self.threshold,
+        }
\ No newline at end of file
