@@ -16,6 +16,7 @@ class TextRCNNClassifier(DeepClassifier):
         sequence_length: int = None,
         segmenter: str = "jieba",
         embedding_size: int = 100,
+        use_batch_normalization: bool = True,
         num_rnn_layers: int = 1,
         rnn_hidden_size: int = 512,
         rnn_projection_size: int = 128,
@@ -51,6 +52,7 @@ class TextRCNNClassifier(DeepClassifier):
             sequence_length=sequence_length,
             segmenter=segmenter,
             embedding_size=embedding_size,
+            use_batch_normalization=use_batch_normalization,
             algorithm="rcnn",
             text2vec=text2vec,
             **kwargs
