@@ -65,14 +65,4 @@ class Word2vec(Text2vec):
             mask_zero=True,
             name="embeddings",
         )
-        self._model = tf.keras.Sequential(embedding, name=name)
-
-    def __call__(self, inputs: tf.Tensor) -> tf.Tensor:
-        return self._model(inputs)
-
-    @property
-    def embedding_size(self) -> int:
-        return self._embedding_size
-
-    def get_config(self) -> Dict[str, Any]:
-        return {**super().get_config(), "embedding_size": self.embedding_size}
+        self._model = tf.keras.Sequential(embedding, name=name)
\ No newline at end of file
